@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2012-2017 Snowflake Computing Inc. All right reserved.
+# Copyright (c) 2012-2018 Snowflake Computing Inc. All right reserved.
 #
 import logging
 import re
@@ -14,7 +14,14 @@ from time import strptime
 
 from . import errors
 from . import network
-from .auth import Auth, DEFAULT_AUTHENTICATOR, EXTERNAL_BROWSER_AUTHENTICATOR
+from .auth import (
+        Auth,
+        DEFAULT_AUTHENTICATOR,
+        EXTERNAL_BROWSER_AUTHENTICATOR,
+        KEY_PAIR_AUTHENTICATOR,
+        OAUTH_AUTHENTICATOR)
+from .auth_keypair import AuthByKeyPair
+from .auth_oauth import AuthByOAuth
 from .auth_okta import AuthByOkta
 from .auth_webbrowser import AuthByWebBrowser
 from .chunk_downloader import SnowflakeChunkDownloader
@@ -60,6 +67,8 @@ DEFAULT_CONFIGURATION = {
     u'network_timeout': None,  # network timeout (infinite by default)
     u'passcode_in_password': False,  # Snowflake MFA
     u'passcode': None,  # Snowflake MFA
+    u'private_key': None,
+    u'token': None,  # OAuth or JWT Token
     u'authenticator': DEFAULT_AUTHENTICATOR,
     u'mfa_callback': None,
     u'password_callback': None,
@@ -78,7 +87,7 @@ DEFAULT_CONFIGURATION = {
     u'chunk_downloader_class': SnowflakeChunkDownloader,  # snowflake internal
     u'validate_default_parameters': False,  # snowflake
     u'probe_connection': False,  # snowflake
-    u'paramstyle': u'pyformat',  # standard/snowflake
+    u'paramstyle': None,  # standard/snowflake
     u'timezone': None,  # snowflake
 }
 
@@ -458,6 +467,10 @@ class SnowflakeConnection(object):
         if self._authenticator != DEFAULT_AUTHENTICATOR:
             if self._authenticator == EXTERNAL_BROWSER_AUTHENTICATOR:
                 auth_instance = AuthByWebBrowser(self.rest, self.application)
+            elif self._authenticator == KEY_PAIR_AUTHENTICATOR:
+                auth_instance = AuthByKeyPair(self._private_key)
+            elif self._authenticator == OAUTH_AUTHENTICATOR:
+                auth_instance = AuthByOAuth(self._token)
             else:
                 auth_instance = AuthByOkta(self.rest, self.application)
             auth_instance.authenticate(
@@ -511,7 +524,10 @@ class SnowflakeConnection(object):
             else:
                 setattr(self, u'_' + name, value)
 
-        if self._paramstyle not in SUPPORTED_PARAMSTYLES:
+        if self._paramstyle is None:
+            import snowflake.connector
+            self._paramstyle = snowflake.connector.paramstyle
+        elif self._paramstyle not in SUPPORTED_PARAMSTYLES:
             raise ProgrammingError(
                 msg=u'Invalid paramstyle is specified',
                 errno=ER_INVALID_VALUE
@@ -535,10 +551,15 @@ class SnowflakeConnection(object):
                     u'errno': ER_NO_USER
                 })
 
+        if self._private_key:
+            self._authenticator = KEY_PAIR_AUTHENTICATOR
+
         if self._authenticator:
             self._authenticator = self._authenticator.upper()
 
-        if self._authenticator != EXTERNAL_BROWSER_AUTHENTICATOR:
+        if self._authenticator != EXTERNAL_BROWSER_AUTHENTICATOR and \
+           self._authenticator != OAUTH_AUTHENTICATOR and \
+           self._authenticator != KEY_PAIR_AUTHENTICATOR:
             # authentication is done by the browser if the authenticator
             # is externalbrowser
             if not self._password:
