@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2012-2017 Snowflake Computing Inc. All right reserved.
+# Copyright (c) 2012-2018 Snowflake Computing Inc. All right reserved.
 #
 import collections
 import contextlib
@@ -28,7 +28,6 @@ from botocore.vendored.requests.packages.urllib3.exceptions import (
     ProtocolError, ReadTimeoutError)
 from botocore.vendored.requests.packages.urllib3.exceptions \
     import SSLError as urllib3_SSLError
-from pyasn1.error import PyAsn1Error
 
 from . import proxy
 from . import ssl_wrap_socket
@@ -52,7 +51,8 @@ from .gzip_decoder import decompress_raw_data
 from .sqlstate import (SQLSTATE_CONNECTION_NOT_EXISTS,
                        SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED,
                        SQLSTATE_CONNECTION_REJECTED)
-from .ssl_wrap_socket import (set_proxies, probe_connection)
+from .ssl_wrap_socket import (set_proxies)
+from .tool.probe_connection import probe_connection
 from .util_text import split_rows_from_stream
 from .version import VERSION
 
@@ -490,7 +490,7 @@ class SnowflakeRestful(object):
             if retry_ctx.timeout is not None:
                 retry_ctx.timeout -= int(time.time() - start_request_thread)
                 if retry_ctx.timeout <= 0:
-                    logger.error(cause)
+                    logger.error(cause, exc_info=True)
                     if isinstance(cause, Error):
                         Error.errorhandler_wrapper(conn, None, cause)
                     else:
@@ -526,7 +526,7 @@ class SnowflakeRestful(object):
                         cause.args[0].args[0], ssl.SSLError):
                     err = cause.args[0].args[0].args[0]
                     if u'bad handshake' in err and \
-                                    u'certificate verify failed' in err:
+                            u'certificate verify failed' in err:
                         if conn.application == APPLICATION_SNOWSQL:
                             # SnowSQL has an option to probe connection.
                             msg = \
@@ -700,10 +700,10 @@ class SnowflakeRestful(object):
                 ProtocolError,  # from urllib3
                 ReadTimeoutError,  # from urllib3
                 OpenSSL.SSL.SysCallError,
+                KeyError,  # SNOW-39175: asn1crypto.keys.PublicKeyInfo
                 ValueError,
                 RuntimeError,
                 AttributeError,  # json decoding error
-                PyAsn1Error  # garbled OCSP response
                 ) as err:
             logger.debug(
                 "Hit retryable client error. Retrying... Ignore the following "
